
# Automaticly generated code. 
# Changes here can get overwritten!

import os


class Api:
    def __init__(self, window):
        self._window = window
    def isdir(self, _path):
            return os.path.isdir(_path)
    def isfile(self, _path):
            return os.path.isfile(_path)
    def mkdir(self, _path):
            os.mkdir(_path)
    def pathExists(self, _path):
            return os.path.exists(_path)
    def readFile(self, _path):
            with open(_path, 'r') as file:
                return file.read()
    def readdir(self, _path):
            return os.listdir(_path)
    def writeFile(self, _path, _content):
            with open(_path, 'w') as file:
                file.write(_content)
    def basename(self, _path):
            return os.path.basename(_path)
    def dirname(self, _path):
            return os.path.dirname(_path)
    def join(self, *paths):
            return os.path.join(*paths)
    def resolve(self, *paths):
            return os.path.abspath(os.path.join(*paths))
    def getWindowInfo(self):
        return {"x": self._window.x, "y": self._window.y, "width": self._window.width, "height": self._window.height}
    def hideWindow(self):
        return self._window.hide()
    def minimizeWindow(self):
        return self._window.minimize()
    def moveWindow(self, _x, _y):
        return self._window.move(_x, _y)
    def resizeWindow(self, _width, _height):
        return self._window.resize(_width, _height)
    def setWindowName(self, _name):
        return self._window.set_title(_name)
    def toggleFullscreen(self):
        return self._window.toggle_fullscreen()
    def unhideWindow(self):
        return self._window.show()
    def unminimizeWindow(self):
        return self._window.restore()


JS_INIT_STRING = "const __Node__ = {'Fs': {'isdir': pywebview.api.isdir, 'isfile': pywebview.api.isfile, 'mkdir': pywebview.api.mkdir, 'pathExists': pywebview.api.pathExists, 'readFile': pywebview.api.readFile, 'readdir': pywebview.api.readdir, 'writeFile': pywebview.api.writeFile}, 'Path': {'basename': pywebview.api.basename, 'dirname': pywebview.api.dirname, 'join': pywebview.api.join, 'resolve': pywebview.api.resolve}};"



import webview
import os
import sys


from .handle_build import handle_build_copy
from .generated import Api

_window = None

build_dir = "./Pequena/build"

base_directory = None
if os.name == 'posix':  # for *nix systems
    base_directory = os.path.join(os.path.expanduser('~'), '.pywebview')
elif os.name == 'nt':  # for Windows
    base_directory = os.path.join(os.environ['APPDATA'], 'pywebview')

exposed_fcs = []


def expose_functions(*fc):
    for f in fc:
        exposed_fcs.append(f)


def init_window(src="client/index.html", window_name="Hello World!", width=800, height=600,
                x=None, y=None, resizable=True, fullscreen=False, min_size=(200, 100),
                hidden=False, frameless=False, easy_drag=True,
                minimized=False, on_top=False, confirm_close=False, background_color='#FFFFFF',
                transparent=False, text_select=False, zoomable=False, draggable=False):
    global _window
    client_dir = os.path.dirname(src)
    build_html = build_dir + "/" + os.path.basename(src)
    if not getattr(sys, 'frozen', False):
        handle_build_copy(client_dir, build_dir, build_html)
    print("Build_html: ", build_html)

    _window = webview.create_window(title=window_name, url=build_html, js_api=Api(_window), width=width, height=height,
                                    x=x, y=y, resizable=resizable, fullscreen=fullscreen, min_size=min_size,
                                    hidden=hidden, frameless=frameless, easy_drag=easy_drag,
                                    minimized=minimized, on_top=on_top, confirm_close=confirm_close, background_color=background_color,
                                    transparent=transparent, text_select=text_select, zoomable=zoomable, draggable=draggable)
    return _window


def start_window(port=None, debug=True):

    for fc in exposed_fcs:
        _window.expose(fc)
    webview.start(gui='edgechromium', debug=debug,
                  http_port=port, storage_path=base_directory)



from setuptools import setup, find_packages

VERSION = "0.0.46"
DESCRIPTION = 'Lightweight desktop app framework'
with open("Readme.md", "r") as fh:
    LONG_DESCRIPTION = fh.read()

setup(
    name="Pequena",
    version=VERSION,
    author="borecjeborec1",
    author_email="<atzuki@protonmail.com>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=['pequenawebview'],
    keywords=['python'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)



from distutils.dir_util import copy_tree
from .generated import JS_INIT_STRING
import os
import re


def check_for_modules(js_path):
    script_dir = os.path.dirname(js_path)
    script_str = ""
    with open(js_path, 'r') as f:
        script_content = f.readlines()

    for line in script_content:
        if ("import" in line):
            import_regex = re.compile(r'from \".+\"|from \'.+\'')
            module_path = script_dir + "/" + import_regex.findall(line)[0].replace("from ", "").replace(
                "\"", "").replace("\'", "")
            script_str += check_for_modules(module_path)
        else:
            if (not "export \{" in line):
                script_str += line.replace("export ", "")
    return script_str + "\n"


def handle_build_copy(_client_dir, _build_dir, _build_html):
    if not os.path.exists(_client_dir):
        return
    try:
        copy_tree(_client_dir, _build_dir)
    except:
        print("error from Copy tree")
        return
    script_str = f"""
<script>
    window.addEventListener('pywebviewready', function () {{
        const __PEQUENA__ = pywebview.api;
        {JS_INIT_STRING}
"""
    new_html = ""
    with open(_build_html, 'r') as f:
        html_content = f.readlines()

    for line in html_content:
        if ("<script" in line):
            if ("src=" in line):
                if ("https://" not in line and "http://" not in line):
                    file_regex = re.compile(r'(?:href|src)="([^"]+)"')
                    js_path = os.path.dirname(_build_html) + \
                        "/" + file_regex.findall(line)[0]
                    if ("type=\"module\"" in line):
                        script_str += check_for_modules(js_path)
                    else:
                        print("JS_PATH: ", js_path)
                        with open(js_path, 'r', errors='ignore') as f:
                            script_str += f.read() + "\n"
                else:
                    new_html += line
        else:
            new_html += line

    new_html = new_html.replace("</body>", script_str + "})</script>\n</body>")
    with open(_build_html, "w") as op:
        op.write(new_html)
